<template>
  <basic-container>
    <!-- 编码规则信息展示区域 -->
    <avue-crud :option="option"
               :table-loading="loading"
               :data="data"
               :page.sync="page"
               :permission="permissionList"
               v-model="form"
               ref="crud"
               :before-open="beforeOpen"
               @row-update="rowUpdate"
               @row-save="rowSave"
               @search-change="searchChange"
               @search-reset="searchReset"
               @selection-change="selectionChange"
               @current-change="currentChange"
               @size-change="sizeChange"
               @refresh-change="refreshChange"
               @on-load="onLoad">
      <!-- 表格内操作按钮 -->
      <template slot="menu" slot-scope="scope">
        <el-button type="text"
                   size="small"
                   icon="el-icon-edit"
                   v-show="scope.row.lcStatusText=='编辑中' ? true:false"
                   plain
                   @click="openEdit(scope.row)">编 辑
        </el-button>
        <el-button type="text"
                   size="small"
                   icon="iconfont iconicon_shakehands"
                   v-show="scope.row.lcStatusText=='编辑中' ? true:false"
                   plain
                   @click="enableOrDeactivatse(scope.row.oid,'release')">发 布
        </el-button>
        <el-button type="text"
                   size="small"
                   v-show="scope.row.lcStatusText=='已发布' ? true:false"
                   icon="iconfont iconicon_details"
                   plain
                   @click="enableOrDeactivatse(scope.row.oid,'disable')">停 用
        </el-button>
        <el-button type="text"
                   size="small"
                   v-show="scope.row.lcStatusText=='停用' ? true:false"
                   icon="iconfont iconicon_task_done"
                   plain
                   @click="enableOrDeactivatse(scope.row.oid,'enable')">启 用
        </el-button>
      </template>
      <!-- 表格左上方按钮区域 -->
      <template slot="menuLeft" slot-scope="scope">
        <el-button type="danger"
                   size="small"
                   icon="el-icon-delete"
                   plain
                   @click="handleDelete">删 除
        </el-button>
        <el-button size="small"
                   icon="el-icon-coin"
                   plain
                   @click="cloneCodeSetting">克 隆
        </el-button>
        <el-button size="small"
                   icon="el-icon-coine"
                   plain
                   @click="handleDelete">从其他规则中克隆码段
        </el-button>
        <el-button size="small"
                   icon="el-icon-notebook-1"
                   plain
                   @click="handleRange">使用范围
        </el-button>
        <el-button size="small"
                   icon="el-icon-notebook-2"
                   plain
                   @click="handleDelete">清空码值
        </el-button>
      </template>
    </avue-crud>
    <!-- 对话框 -->
    <el-dialog title="编码规则使用范围"
               append-to-body
               :visible.sync="codeRangeSettingBox"
               width="800px">
      <avue-crud
              :option="dialogeOption" 
              :table-loading="dialogLoading"
              :data="useRangeData"
              @refresh-change="refreshUseRangeChange"></avue-crud>
    </el-dialog>
    <!-- 克隆对话框 -->
    <el-dialog title="克隆编码规则"
               append-to-body
               :visible.sync="cloneSettingBox"
               width="800px">
      <clone-code></clone-code>
    </el-dialog>

    <!-- 基础编码信息 -->

  </basic-container>
</template>

<script>
  import {gridCodeRule, getDetail, add, update, remove, listUseRange, updateStatus} from "@/api/code/mdmrule";
  import option from "@/const/code/mdmrule";
  import {mapGetters} from "vuex";
export default {
    data() {
      return {
        form: {},
        query: {},
        loading: true,
        
        page: {
          pageSize: 10,
          currentPage: 1,
          total: 0
        },
        selectionList: [],
        option: option,
        data: [],

        /*使用范围*/
        codeRangeSettingBox: false,
        /*克隆弹窗*/
        cloneSettingBox: false,
        useRangeData: [],
        dialogLoading: true,
        /*使用范围对话框*/
        dialogeOption: {
        height: 'auto',
        calcHeight: 30,
        tip: false,
        searchShow: false,
        searchMenuSpan: 6,
        border: true,
        index: true,
        disablePage:false,
        viewBtn: false,
        addBtn: false,
        menu: false,
        selection: false,
        dialogClickModal: false,
        align: 'center',
        dialogWidth: 400,
        column: [
          {
            label: "分类编号",
            prop: "id",
            span: 24
          },
          {
            label: "分类名称",
            prop: "name",
            span: 24,
          }
        ]
      },
      };
    },
    computed: {
      ...mapGetters(["permission"]),
      permissionList() {
        return {
          addBtn: this.vaildData(this.permission.codeRule_add, true),
          viewBtn: this.vaildData(this.permission.codeRule_view, false),
          delBtn: this.vaildData(this.permission.plCodeRule_delete, false),
          editBtn: this.vaildData(this.permission.codeRule_edit, true)
        };
      },
    },
    methods: {
      //查询使用范围
      handleRange(){
        if (this.selectionList.length === 0) {
          this.$message.warning("请选择至少一条数据!");
          return;
        }
        if (this.selectionList.length > 1) {
          this.$message.warning("每次只能选择一条数据!");
          return;
        }
        this.codeRangeSettingBox = true;
        this.getRangeCodeList()
      },
      getRangeCodeList(){        
        this.dialogLoading = true;
        if(this.selectionList[0].oid==null){
          this.$message.error("未获取到参数!");
        }

        listUseRange(this.selectionList[0].oid).then(res => {
          this.useRangeData = res.data.data;
          //console.log(this.useRangeData);
          this.dialogLoading = false;
        });
      },
      refreshUseRangeChange(){
        this.getRangeCodeList();
      },
      //启用与停用
      enableOrDeactivatse(oId,update){
        updateStatus({"oid":oId,"ts":new Date().getTime,"update":update}).then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        }, error => {
          window.console.log(error);
        });
      },
      //克隆
      cloneCodeSetting() {
        if (this.selectionList.length === 0) {
          this.$message.warning("请选择至少一条数据!");
          return;
        }
        if (this.selectionList.length > 1) {
          this.$message.warning("每次只能选择一条数据!");
          return;
        }
        localStorage.setItem("cloneOid",this.selectionList[0].oid)
        this.cloneSettingBox = true;
      },
      
      // 添加
      rowSave(row, done, loading) {
        add(row).then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          done();
        }, error => {
          loading();
          window.console.log(error);
        });
      },
      openEdit(row){
        this.$refs.crud.rowEdit(row,row.$index);
      },
      // 修改
      rowUpdate(row, index, done, loading) {
        row.ts = new Date().getTime;
        update(row).then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
          done();
        }, error => {
          loading();
          console.log(error);
        });
      },
      // 删除
      handleDelete() {
        if (this.selectionList.length === 0) {
          this.$message.warning("请选择至少一条数据");
          return;
        }
        if (this.selectionList.length > 1) {
          this.$message.warning("每次只能选择一条数据");
          return;
        }
        this.$confirm("确定将选择数据删除?", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        })
          .then(() => {
            let ts = new Date().getTime();
            // 只支持每次单条记录删除
            let oid = this.selectionList[0].oid
            return remove({oid: oid,ts: ts});
          })
          .then(() => {
            this.onLoad(this.page);
            this.$message({
              type: "success",
              message: "操作成功!"
            });
            this.$refs.crud.toggleSelection();
          });
      },
      //打开修改
      beforeOpen(done, type) {
        if (["edit", "view"].includes(type)) {
          getDetail(this.form.oid).then(res => {
            this.form = res.data.data;
          });
        }
        done();
      },
      searchReset() {
        this.query = {};
        this.onLoad(this.page);
      },
      searchChange(params, done) {
        this.query = params;
        this.page.currentPage = 1;
        this.onLoad(this.page, params);
        done();
      },
      selectionChange(list) {
        this.selectionList = list;
      },
      selectionClear() {
        this.selectionList = [];
        this.$refs.crud.toggleSelection();
      },
      currentChange(currentPage){
        this.page.currentPage = currentPage;
      },
      sizeChange(pageSize){
        this.page.pageSize = pageSize;
      },
      refreshChange() {
        this.onLoad(this.page, this.query);
      },
      onLoad(page, params = {}) {
        this.loading = true;
        gridCodeRule(page.currentPage, page.pageSize, Object.assign(params, this.query)).then(res => {
          //console.log(res);
          const data = res.data.data;
          this.page.total = data.total;
          this.data = data.records;
          this.loading = false;
          this.selectionClear();
        });
      }
    }
  };
</script>

<style>
</style>